@@ -78,14 +78,14 @@ class Network:
                 f.write('{}')
         _info = json.load(open(local_file, 'r'))
 
-        proxy_type = 'http' if proxy_str.startswith('http') else 'socks5'
+        proxy_type = 'https' if proxy_str.startswith('http') else 'socks5'
         if not Network.is_good_proxy(proxy_str, proxy_type):
             failed_count = _info.get(proxy_str, 0) + 1
             if failed_count >= 30:
                 msg = str(_info)
                 ym = YahooMail()
                 ym.send(decode('foxmail'), '代理失效', msg)
-                failed_count = -1410  # Check every minute, alert once per day.
+                failed_count = -1410     # Check every minute, alert once per day.
             _info[proxy_str] = failed_count
         else:
             _info[proxy_str] = 0
